@@ -37,7 +37,7 @@ package Time::OlsonTZ::Data;
 use warnings;
 use strict;
 
-our $VERSION = "0.202401";
+our $VERSION = "0.202402";
 
 use parent "Exporter";
 our @EXPORT_OK = qw(
@@ -77,7 +77,7 @@ retain this format in the future.
 
 =cut
 
-use constant olson_version => "2024a";
+use constant olson_version => "2024b";
 
 =item olson_code_version
 
@@ -89,7 +89,7 @@ piece of information.
 
 =cut
 
-use constant olson_code_version => "2024a";
+use constant olson_code_version => "2024b";
 
 =item olson_data_version
 
@@ -101,7 +101,7 @@ piece of information.
 
 =cut
 
-use constant olson_data_version => "2024a";
+use constant olson_data_version => "2024b";
 
 =back
 
@@ -166,46 +166,45 @@ my $cn = q(+{ map { ($_ => undef) } qw(
 	Antarctica/Palmer Antarctica/Rothera Antarctica/Troll Antarctica/Vostok
 	Asia/Almaty Asia/Amman Asia/Anadyr Asia/Aqtau Asia/Aqtobe Asia/Ashgabat
 	Asia/Atyrau Asia/Baghdad Asia/Baku Asia/Bangkok Asia/Barnaul Asia/Beirut
-	Asia/Bishkek Asia/Chita Asia/Choibalsan Asia/Colombo Asia/Damascus
-	Asia/Dhaka Asia/Dili Asia/Dubai Asia/Dushanbe Asia/Famagusta Asia/Gaza
-	Asia/Hebron Asia/Ho_Chi_Minh Asia/Hong_Kong Asia/Hovd Asia/Irkutsk
-	Asia/Jakarta Asia/Jayapura Asia/Jerusalem Asia/Kabul Asia/Kamchatka
-	Asia/Karachi Asia/Kathmandu Asia/Khandyga Asia/Kolkata Asia/Krasnoyarsk
-	Asia/Kuching Asia/Macau Asia/Magadan Asia/Makassar Asia/Manila
-	Asia/Nicosia Asia/Novokuznetsk Asia/Novosibirsk Asia/Omsk Asia/Oral
-	Asia/Pontianak Asia/Pyongyang Asia/Qatar Asia/Qostanay Asia/Qyzylorda
-	Asia/Riyadh Asia/Sakhalin Asia/Samarkand Asia/Seoul Asia/Shanghai
-	Asia/Singapore Asia/Srednekolymsk Asia/Taipei Asia/Tashkent Asia/Tbilisi
-	Asia/Tehran Asia/Thimphu Asia/Tokyo Asia/Tomsk Asia/Ulaanbaatar
-	Asia/Urumqi Asia/Ust-Nera Asia/Vladivostok Asia/Yakutsk Asia/Yangon
+	Asia/Bishkek Asia/Chita Asia/Colombo Asia/Damascus Asia/Dhaka Asia/Dili
+	Asia/Dubai Asia/Dushanbe Asia/Famagusta Asia/Gaza Asia/Hebron
+	Asia/Ho_Chi_Minh Asia/Hong_Kong Asia/Hovd Asia/Irkutsk Asia/Jakarta
+	Asia/Jayapura Asia/Jerusalem Asia/Kabul Asia/Kamchatka Asia/Karachi
+	Asia/Kathmandu Asia/Khandyga Asia/Kolkata Asia/Krasnoyarsk Asia/Kuching
+	Asia/Macau Asia/Magadan Asia/Makassar Asia/Manila Asia/Nicosia
+	Asia/Novokuznetsk Asia/Novosibirsk Asia/Omsk Asia/Oral Asia/Pontianak
+	Asia/Pyongyang Asia/Qatar Asia/Qostanay Asia/Qyzylorda Asia/Riyadh
+	Asia/Sakhalin Asia/Samarkand Asia/Seoul Asia/Shanghai Asia/Singapore
+	Asia/Srednekolymsk Asia/Taipei Asia/Tashkent Asia/Tbilisi Asia/Tehran
+	Asia/Thimphu Asia/Tokyo Asia/Tomsk Asia/Ulaanbaatar Asia/Urumqi
+	Asia/Ust-Nera Asia/Vladivostok Asia/Yakutsk Asia/Yangon
 	Asia/Yekaterinburg Asia/Yerevan Atlantic/Azores Atlantic/Bermuda
 	Atlantic/Canary Atlantic/Cape_Verde Atlantic/Faroe Atlantic/Madeira
 	Atlantic/South_Georgia Atlantic/Stanley Australia/Adelaide
 	Australia/Brisbane Australia/Broken_Hill Australia/Darwin
 	Australia/Eucla Australia/Hobart Australia/Lindeman Australia/Lord_Howe
-	Australia/Melbourne Australia/Perth Australia/Sydney CET CST6CDT EET EST
-	EST5EDT Etc/GMT Etc/GMT+1 Etc/GMT+10 Etc/GMT+11 Etc/GMT+12 Etc/GMT+2
-	Etc/GMT+3 Etc/GMT+4 Etc/GMT+5 Etc/GMT+6 Etc/GMT+7 Etc/GMT+8 Etc/GMT+9
-	Etc/GMT-1 Etc/GMT-10 Etc/GMT-11 Etc/GMT-12 Etc/GMT-13 Etc/GMT-14
-	Etc/GMT-2 Etc/GMT-3 Etc/GMT-4 Etc/GMT-5 Etc/GMT-6 Etc/GMT-7 Etc/GMT-8
-	Etc/GMT-9 Etc/UTC Europe/Andorra Europe/Astrakhan Europe/Athens
-	Europe/Belgrade Europe/Berlin Europe/Brussels Europe/Bucharest
-	Europe/Budapest Europe/Chisinau Europe/Dublin Europe/Gibraltar
-	Europe/Helsinki Europe/Istanbul Europe/Kaliningrad Europe/Kirov
-	Europe/Kyiv Europe/Lisbon Europe/London Europe/Madrid Europe/Malta
-	Europe/Minsk Europe/Moscow Europe/Paris Europe/Prague Europe/Riga
-	Europe/Rome Europe/Samara Europe/Saratov Europe/Simferopol Europe/Sofia
-	Europe/Tallinn Europe/Tirane Europe/Ulyanovsk Europe/Vienna
-	Europe/Vilnius Europe/Volgograd Europe/Warsaw Europe/Zurich Factory HST
-	Indian/Chagos Indian/Maldives Indian/Mauritius MET MST MST7MDT PST8PDT
-	Pacific/Apia Pacific/Auckland Pacific/Bougainville Pacific/Chatham
-	Pacific/Easter Pacific/Efate Pacific/Fakaofo Pacific/Fiji
-	Pacific/Galapagos Pacific/Gambier Pacific/Guadalcanal Pacific/Guam
-	Pacific/Honolulu Pacific/Kanton Pacific/Kiritimati Pacific/Kosrae
-	Pacific/Kwajalein Pacific/Marquesas Pacific/Nauru Pacific/Niue
-	Pacific/Norfolk Pacific/Noumea Pacific/Pago_Pago Pacific/Palau
-	Pacific/Pitcairn Pacific/Port_Moresby Pacific/Rarotonga Pacific/Tahiti
-	Pacific/Tarawa Pacific/Tongatapu WET
+	Australia/Melbourne Australia/Perth Australia/Sydney Etc/GMT Etc/GMT+1
+	Etc/GMT+10 Etc/GMT+11 Etc/GMT+12 Etc/GMT+2 Etc/GMT+3 Etc/GMT+4 Etc/GMT+5
+	Etc/GMT+6 Etc/GMT+7 Etc/GMT+8 Etc/GMT+9 Etc/GMT-1 Etc/GMT-10 Etc/GMT-11
+	Etc/GMT-12 Etc/GMT-13 Etc/GMT-14 Etc/GMT-2 Etc/GMT-3 Etc/GMT-4 Etc/GMT-5
+	Etc/GMT-6 Etc/GMT-7 Etc/GMT-8 Etc/GMT-9 Etc/UTC Europe/Andorra
+	Europe/Astrakhan Europe/Athens Europe/Belgrade Europe/Berlin
+	Europe/Brussels Europe/Bucharest Europe/Budapest Europe/Chisinau
+	Europe/Dublin Europe/Gibraltar Europe/Helsinki Europe/Istanbul
+	Europe/Kaliningrad Europe/Kirov Europe/Kyiv Europe/Lisbon Europe/London
+	Europe/Madrid Europe/Malta Europe/Minsk Europe/Moscow Europe/Paris
+	Europe/Prague Europe/Riga Europe/Rome Europe/Samara Europe/Saratov
+	Europe/Simferopol Europe/Sofia Europe/Tallinn Europe/Tirane
+	Europe/Ulyanovsk Europe/Vienna Europe/Vilnius Europe/Volgograd
+	Europe/Warsaw Europe/Zurich Factory Indian/Chagos Indian/Maldives
+	Indian/Mauritius Pacific/Apia Pacific/Auckland Pacific/Bougainville
+	Pacific/Chatham Pacific/Easter Pacific/Efate Pacific/Fakaofo
+	Pacific/Fiji Pacific/Galapagos Pacific/Gambier Pacific/Guadalcanal
+	Pacific/Guam Pacific/Honolulu Pacific/Kanton Pacific/Kiritimati
+	Pacific/Kosrae Pacific/Kwajalein Pacific/Marquesas Pacific/Nauru
+	Pacific/Niue Pacific/Norfolk Pacific/Noumea Pacific/Pago_Pago
+	Pacific/Palau Pacific/Pitcairn Pacific/Port_Moresby Pacific/Rarotonga
+	Pacific/Tahiti Pacific/Tarawa Pacific/Tongatapu
 ) });
 sub olson_canonical_names() {
 	$cn = eval($cn) || die $@ if ref($cn) eq "";
@@ -350,6 +349,7 @@ my $li = q(+{
 	"Asia/Bahrain" => "Asia/Qatar",
 	"Asia/Brunei" => "Asia/Kuching",
 	"Asia/Calcutta" => "Asia/Kolkata",
+	"Asia/Choibalsan" => "Asia/Ulaanbaatar",
 	"Asia/Chongqing" => "Asia/Shanghai",
 	"Asia/Chungking" => "Asia/Shanghai",
 	"Asia/Dacca" => "Asia/Dhaka",
@@ -389,6 +389,8 @@ my $li = q(+{
 	"Brazil/DeNoronha" => "America/Noronha",
 	"Brazil/East" => "America/Sao_Paulo",
 	"Brazil/West" => "America/Manaus",
+	CET => "Europe/Brussels",
+	CST6CDT => "America/Chicago",
 	"Canada/Atlantic" => "America/Halifax",
 	"Canada/Central" => "America/Winnipeg",
 	"Canada/Eastern" => "America/Toronto",
@@ -400,6 +402,9 @@ my $li = q(+{
 	"Chile/Continental" => "America/Santiago",
 	"Chile/EasterIsland" => "Pacific/Easter",
 	Cuba => "America/Havana",
+	EET => "Europe/Athens",
+	EST => "America/Panama",
+	EST5EDT => "America/New_York",
 	Egypt => "Africa/Cairo",
 	Eire => "Europe/Dublin",
 	"Etc/GMT+0" => "Etc/GMT",
@@ -442,6 +447,7 @@ my $li = q(+{
 	"GMT-0" => "Etc/GMT",
 	GMT0 => "Etc/GMT",
 	Greenwich => "Etc/GMT",
+	HST => "Pacific/Honolulu",
 	Hongkong => "Asia/Hong_Kong",
 	Iceland => "Africa/Abidjan",
 	"Indian/Antananarivo" => "Africa/Nairobi",
@@ -458,6 +464,9 @@ my $li = q(+{
 	Japan => "Asia/Tokyo",
 	Kwajalein => "Pacific/Kwajalein",
 	Libya => "Africa/Tripoli",
+	MET => "Europe/Brussels",
+	MST => "America/Phoenix",
+	MST7MDT => "America/Denver",
 	"Mexico/BajaNorte" => "America/Tijuana",
 	"Mexico/BajaSur" => "America/Mazatlan",
 	"Mexico/General" => "America/Mexico_City",
@@ -465,6 +474,7 @@ my $li = q(+{
 	"NZ-CHAT" => "Pacific/Chatham",
 	Navajo => "America/Denver",
 	PRC => "Asia/Shanghai",
+	PST8PDT => "America/Los_Angeles",
 	"Pacific/Chuuk" => "Pacific/Port_Moresby",
 	"Pacific/Enderbury" => "Pacific/Kanton",
 	"Pacific/Funafuti" => "Pacific/Tarawa",
@@ -501,6 +511,7 @@ my $li = q(+{
 	UTC => "Etc/UTC",
 	Universal => "Etc/UTC",
 	"W-SU" => "Europe/Moscow",
+	WET => "Europe/Lisbon",
 	Zulu => "Etc/UTC",
 });
 sub olson_links() {
